Except for container every function specified here should be
vectorized and apply formatting to each element in a character vectors. The
functions must accept at least one argument and require no more than one
argument. The text to be formatted will be passed as a character vector
as the first argument to each function.
StyleFuns(...)a StyleFuns S4 object
named values for the slots described in the “Constructor Arguments” section below; all are optional
containerfunction used primarily by HTML styles to generate an
outermost DIV that allows for CSS targeting of its contents
(see cont_f for a function generator appropriate for use
here)
linefunction
line.insertfunction
line.deletefunction
line.matchfunction
line.guidefunction formats guide lines (see guides)
textfunction
text.insertfunction
text.deletefunction
text.matchfunction
text.guidefunction formats guide lines (see guides)
gutterfunction
gutter.insertfunction
gutter.deletefunction
gutter.matchfunction
gutter.guidefunction
gutter.padfunction
headerfunction to format each hunk header with
bannerfunction to format entire banner
banner.insertfunction to format insertion banner
banner.deletefunction to format deletion banner
metafunction format meta information lines
context.sepfunction to format the separator used to visually
distinguish the A and B hunks in “context” mode
These functions are applied in post processing steps. The diff*
methods do not do any of the formatting. Instead, the formatting is done
only if the user requests to show the object. Internally, show
first converts the object to a character vector using as.character,
which applies every formatting function defined here except for
container. Then show applies container before
forwarding the result to the screen or pager.
Style