diffobj_set_def_opts: Set All diffobj Options to Defaults

View source: R/options.R

diffobj_set_def_optsR Documentation

Set All diffobj Options to Defaults

Description

Used primarily for testing to ensure all options are set to default values.

Usage

diffobj_set_def_opts()

Value

list for use with options that contains values of diffob options before they were forced to defaults

Examples

## Not run: 
  diffobj_set_def_opts()

## End(Not run)

diffobj documentation built on July 18, 2026, 1:07 a.m.